import os
import sys

# 프로젝트 루트 디렉터리와 관련된 모든 스크립트 디렉터리를 sys.path에 추가합니다.
project_root = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', '..'))
scripts_dir = os.path.join(project_root, 'scripts')
config_dir = os.path.join(project_root, 'config')
utils_dir = os.path.join(scripts_dir, 'utils')

sys.path.extend([
    scripts_dir,
    os.path.join(scripts_dir, 'data_collection'),
    os.path.join(scripts_dir, 'data_processing'),
    os.path.join(scripts_dir, 'model'),
    os.path.join(scripts_dir, 'trading'),
    utils_dir
])

sys.path.append(config_dir)

# 필요한 모듈 가져오기
from data_processing.data_preprocessing import normalize_data
from model.main_model_training import ModelTrainer
from trading.backtesting import Backtester
from utils.performance_monitoring import PerformanceMonitor

def main():
    # Step 1: Data Preprocessing
    print("Starting data preprocessing...")
    # 데이터프레임 예시로 생성 (실제로는 실제 데이터를 사용해야 함)
    sample_data = pd.DataFrame({
        'feature1': [1.0, 2.0, 3.0],
        'feature2': [4.0, 5.0, 6.0]
    })
    processed_data = normalize_data(sample_data)

    # Step 2: Model Training
    print("Starting model training...")
    model_trainer = ModelTrainer()
    trained_model = model_trainer.train(processed_data)

    # Step 3: Backtesting
    print("Starting backtesting...")
    backtester = Backtester()
    backtest_results = backtester.run_backtest(trained_model)

    # Step 4: Performance Monitoring
    print("Monitoring performance...")
    performance_monitor = PerformanceMonitor()
    performance_monitor.monitor(backtest_results)

    print("Main workflow completed successfully.")

if __name__ == "__main__":
    main()
